/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.support.test.jank;

import android.os.Bundle;

/**
 * An interface used to define a class that monitors test methods and collects metrics.
 */
public interface IMonitor {

    /**
     * Begin monitoring a test method.
     */
    public void startIteration() throws Throwable;

    /**
     * Stop monitoring a test method and return intermediate results for this iteration.
     *
     * @return A {@link Bundle} of test results.
     */
    public Bundle stopIteration() throws Throwable;

    /**
     * Get the summary results accross all iterations.
     */
    public Bundle getMetrics();
}
